@@ -1,3 +1,13 @@
+#
+# (C) Copyright 2013 Enthought, Inc., Austin, TX
+# All right reserved.
+#
+# This file is open source software distributed according to the terms in
+# LICENSE.txt
+#
+
+from __future__ import absolute_import
+
 from traits.api import Interface
 
 class IAdapterManager(Interface):
